<!--

// QTVR Properties v0.4  By Eric Gerds   http://www.pinlady.net/vr
// This code will display the current pan,tilt,fov of a QTVR movie

var G = new Object();

// Defaults
G.srcdefault = 'pano.mov';
G.widthdefault = '100%';
G.heightdefault = '100%';
G.controldefault = false;
G.cachedefault = true;
G.scaledefault = 'tofit';
G.kioskdefault = true;
G.bgcolordefault = '#000000';
G.fullscreendefault = true;


// Initialize the embed/object tag parameters for the QTVR
function initall(){

if (typeof document.getElementById != "undefined"){
   document.getElementById("width").value = G.widthdefault;
   document.getElementById("height").value = G.heightdefault;
   document.getElementById("controller").checked = G.controldefault;
   document.getElementById("bgcolor").value = G.bgcolordefault;
   document.getElementById("cache").checked = G.cachedefault;
   document.getElementById("scale").value = G.scaledefault;
   document.getElementById("kiosk").checked = G.kioskdefault;
   document.getElementById("fullscreen").checked = G.fullscreendefault;
   return
}


// We cannot initialize the 'src' field due to security reasons
// document.getElementById("src").value = G.srcdefault;


}

// Verify that the QuickTime movie is a QTVR.
// If it is not, then return false.
// If it is a QTVR movie, then return true.
function isVR(){
var tmp = getprop(G.win.document,'GetIsVRMovie()');
if (tmp==true){
   document.getElementById("misc").innerHTML = "";
   return true
 };
if (tmp==false){
   document.getElementById("misc").innerHTML = "Error! " +
   "This is not a QTVR movie. Pan/Tilt/Fov will not be displayed."
   return false
};

return false;

}


// Get all the numbers in the QuickTime matrix.
function getthematrix(){
var aa = getprop(G.win.document,'GetMatrix()');
if (aa==null){return null};

// Find the carriage returns
var n1 = aa.indexOf(String.fromCharCode(13),0);
var n2 = aa.indexOf(String.fromCharCode(13),n1+1);

var row1 = aa.slice(0,n1-1);
var row2 = aa.slice(n1+1,n2-1);
var row3 = aa.slice(n2+1,aa.length-1);

var c1,c2,x11,x12,x13,x21,x22,x23,x31,x32,x33

c1 = row1.indexOf(",",0);   // get index of comma after index 0
c2 = row1.indexOf(",",c1+1);  // index of comma 2
x11 = row1.substring(0,c1); // get characters from 0 to c1 - 1
x12 = row1.substring(c1+1,c2);
x13 = row1.substring(c2+1,row1.length);

c1 = row2.indexOf(",",0);
c2 = row2.indexOf(",",c1+1);
x21 = row2.substring(0,c1);
x22 = row2.substring(c1+1,c2);
x23 = row2.substring(c2+1,row2.length);

c1 = row3.indexOf(",",0);
c2 = row3.indexOf(",",c1+1);
x31 = row3.substring(0,c1);
x32 = row3.substring(c1+1,c2);
x33 = row3.substring(c2+1,row3.length);

// Convert to numbers. We make sure they are integers.
// The matrix only has 4 decimal places. It turns out that if
// you try to put numbers INTO the matrix with too many decimal
// places, then the QT movie will crash.
var z = 10000; // Matrix only holds 4 decimal places
x11=Math.round(x11*z)/z; x12=Math.round(x12*z)/z; x13=Math.round(x13*z)/z;
x21=Math.round(x21*z)/z; x22=Math.round(x22*z)/z; x23=Math.round(x23*z)/z;
x31=Math.round(x31*z)/z; x32=Math.round(x32*z)/z; x33=Math.round(x33*z)/z;

return([x11,x12,x13,x21,x22,x23,x31,x32,x33]);
}


// Return the rectangle coordinates of a QT movie.
function getQTRectangle(){
// rect is a string with 3 commas
var rect = getprop(G.win.document,'GetRectangle()');
if (rect==null){return null}; // QT property for rectangle not found;

var c1 = rect.indexOf(",",0);   // get index of comma after index 0
var c2 = rect.indexOf(",",c1+1);  // index of comma 2
var c3 = rect.indexOf(",",c2+1);  // index of comma 3
var x1 = rect.substring(0,c1); // get characters from 0 to c1 - 1
var y1 = rect.substring(c1+1,c2);
var x2 = rect.substring(c2+1,c3);
var y2 = rect.substring(c3+1,rect.length);

// Convert to numbers. We make sure they are integers.
x1 = Math.round(x1*1); y1 = Math.round(y1*1);
x2 = Math.round(x2*1); y2 = Math.round(y2*1);

return([x1,y1,x2,y2]); // return the coordinates

}

// Calculate default width,default height of a QT movie.
// We calculate this from the QT rectangle and the matrix.
// We assume here that the rectangle has nonzero width and height.
function calcDefaultMovieSize(){
var rect = getQTRectangle();
var mat = getthematrix();

if (rect[2]==rect[0]||rect[3]==rect[1]||mat[0]==0||mat[4]==0){return [0,0]};

 // Must be integer
var QTdefaultwidth = Math.round((rect[2]-rect[0])/mat[0]);
var QTdefaultheight = Math.round((rect[3]-rect[1])/mat[4]);

return [QTdefaultwidth,QTdefaultheight];
}

// Calculate the cube face width (for cubic panos)
function calccubeface(){
var fov = getprop(G.win.document,'GetFieldOfView()');
if (fov==null){return 0};
var fovrad = fov * Math.PI/180; // convert from degrees to radians
var rect = getQTRectangle();
var displayheight = rect[3] - rect[1];
var mat = getthematrix(); // matrix is relative to default movie size

// Display height corresponding to 90 degrees fov at the current zoom level
var cubeface = displayheight / (mat[4]*Math.tan(fovrad/2));

return cubeface;
}

// Print out misc stuff about the QTVR
function miscstuff(){
var QTversion =  "<br>QuickTime Version: " +
            getprop(G.win.document,'GetQuickTimeVersion()');
var QTplugin = "<br>Plugin Version: " +
              getprop(G.win.document,'GetPluginVersion()');
var Moviename = "<br>Movie Name: " + getprop(G.win.document,'GetMovieName()');
var Moviesize = getprop(G.win.document,'GetMovieSize()');

var numtracks = getprop(G.win.document,'GetTrackCount()');
var tracks=""
for (var x=1;x<=numtracks;x++){
 tracks+="<br>&nbsp;&nbsp;&nbsp;&nbsp;Track " + x + ": " +
   getprop(G.win.document,'GetTrackName()',x) + "&nbsp;&nbsp;&nbsp;" +
   getprop(G.win.document,'GetTrackType()',x);
 }
numtracks = "<br><br># QuickTime Tracks: " + numtracks;

var tmp;
var userdata="";
tmp = getprop(G.win.document,'GetUserData(\'nam\')');
if (tmp!=""){userdata+="<br>" + tmp};

tmp = getprop(G.win.document,'GetUserData(\'cpy\')');
if (tmp!=""){userdata+="<br>Copyright: " + tmp};

tmp = getprop(G.win.document,'GetUserData(\'day\')');
if (tmp!=""){userdata+="<br>" + tmp};

tmp = getprop(G.win.document,'GetUserData(\'dir\')');
if (tmp!=""){userdata+="<br>" + tmp};

tmp = getprop(G.win.document,'GetUserData(\'fmt\')');
if (tmp!=""){userdata+="<br>" + tmp};

tmp = getprop(G.win.document,'GetUserData(\'inf\')');
if (tmp!=""){userdata+="<br>" + tmp};

tmp = getprop(G.win.document,'GetUserData(\'prd\')');
if (tmp!=""){userdata+="<br>" + tmp};

tmp = getprop(G.win.document,'GetUserData(\'src\')');
if (tmp!=""){userdata+="<br>" + tmp};

tmp = getprop(G.win.document,'GetUserData(\'wrt\')');
if (tmp!=""){userdata+="<br>" + tmp};


// Get hotspots
var hotspots = "",x;
for (x=1;x<30;x++){
  tmp = getprop(G.win.document,'GetHotspotUrl(' + x + ')');
  if (tmp!=null && tmp!=""){hotspots += "<br>Hotspot #" + x + " URL: " + tmp};
}
if (hotspots!=""){hotspots="<br>" + hotspots};


// Get the default movie size
tmp = calcDefaultMovieSize();
var defsize = "<br><br>Default Movie Size: " + tmp[0] + " x " + tmp[1];

// Get size of display window in browser
var rect = getQTRectangle();
var displaywin = "<br>Size of Display Window: " + (rect[2]-rect[0]) +
  " x " + (rect[3]-rect[1]);

// Is it possible to calculate the cube face size? No


if (typeof document.getElementById != "undefined"){
   document.getElementById("misc").innerHTML =
      QTversion + QTplugin +
      numtracks + tracks +
      defsize + displaywin + userdata + 
      hotspots;
   }
}



// Open a new web page with the QTVR
function openwin(){
t = document.getElementById("fullscreen").checked;

var wf =  "resizable=yes";
wf = wf + ",scrollbars=no";
wf = wf + ",menubar=no";
wf = wf + ",toolbar=no";
wf = wf + ",directories=no";
wf = wf + ",location=no";
wf = wf + ",status=no";

if (!t){wf=''};

// We specify a target window of testqtvrpano, so that
// only one pano window can be open at any given time.
if (!G.win || G.win.closed){
G.win = window.open('','testqtvrpano',wf);
}

// Get the current directory
var baseRef = location.href.substring(0,location.href.lastIndexOf("/") + 1);

var width = document.getElementById("width").value;
var height = document.getElementById("height").value;
var controller =  document.getElementById("controller").checked;
var bgcolor = document.getElementById("bgcolor").value;
var cache = document.getElementById("cache").checked;
var scale = document.getElementById("scale").value;
var kiosk = document.getElementById("kiosk").checked;
var src = document.getElementById("src").value;

// Get src qtvr movie.
// We must decide whether the movie is local or on the internet.
// Local would be file:///C:/stuff/mypano.mov
// Internet would be http://www.mywebsite.com/stuff/pano.mov
if (src==null || src==""){src = baseRef + G.srcdefault};

// If src does not specify file: or http: then we assume it is
// local and add file:/// to the beginning
if (src.indexOf("file://")==-1 && src.indexOf("http://")==-1){
    src = "file:///" + src };                                                      

makeqtvrpage(width,height,src,
  controller,cache,scale,bgcolor,kiosk);

if (G.win && !G.win.closed){G.win.focus()};

}




// Return the .comm property/method value for the embed tag (id = vieweremb)
// or the object tag (id = viewerobj).
// Else return NULL if property not found.
//
// It is assumed here that comm will actually return a value.
// comm can be of the form: 'PropertyName' or 'MethodName()'
// comm and arg are strings.
//
// arg is optional.
// If arg is supplied, then this means we have a method : comm(arg)
//
// Example: for method BlaBla(5) we could have comm='BlaBla(5)'
//  OR comm='BlaBla()' & arg='5'
// For method BlaBla("5") we would have comm='BlaBla(\'5\')'
//  OR comm='BlaBla()' & arg='\'5\''
//
// Note: QT 5 cannot use Javascript with IE, but QT6 can. Also, not
// all browsers may allow browser javascipt to QT interaction.
function getprop(win,comm,arg){
var a="",e;

if (arg) {
  comm = comm.replace(/\)$/,""); // Get rid of ) at end of comm string
  comm += arg + ")"              // insert arg
}


// If .comm property does not exist, then try the viewerobj tag instead.
// If it does exist, but its VALUE is undefined, then try the viewerobj tag.
if (typeof win.getElementById != "undefined" && 
    typeof win.getElementById("viewerobj") != "undefined"){
  try{
    eval("a = win.getElementById(\"viewerobj\")." + comm);
    if (typeof a != "undefined"){return a};
             }
  catch(e){};
    }


if (typeof win.getElementById != "undefined" &&
    typeof win.getElementById("vieweremb") != "undefined" ){
  try{
    eval("a = win.getElementById(\"vieweremb\")." + comm);
    if (typeof a != "undefined"){return a};
             }
  catch(e){};
    }
    
if (typeof win.viewerobj != "undefined"){
  try{
    eval("a = win.viewerobj." + comm);
    if (typeof a != "undefined"){return a};
             }
  catch(e){};
    }
    
if (typeof win.vieweremb != "undefined"){
  try{
    eval("a = win.vieweremb." + comm);
    if (typeof a != "undefined"){return a};
             }
  catch(e){};
    }

return(null); // Return null if .comm property/method does not exist,
              // OR if it exists but has undefined value.
}


// Execute QuickTime method 'comm'
// comm and arg are strings.
// Return true if successful, false otherwise.
//
// win is a reference to the window
function runprop(win,comm,arg){
var e;

if (arg) {
  comm = comm.replace(/\)$/,"");
  comm += arg + ")"
}

if (typeof win.getElementById != "undefined" &&
    typeof win.getElementById("viewerobj") != "undefined"){
  try{
    eval("win.getElementById(\"viewerobj\")." + comm);
    return true;
             }
  catch(e){};
    }


if (typeof win.getElementById != "undefined" &&
    typeof win.getElementById("vieweremb") != "undefined"){
  try{
    eval("win.getElementById(\"vieweremb\")." + comm);
    return true;
             }
  catch(e){};
    }
    
if (typeof win.viewerobj != "undefined"){
  try{
    eval("win.viewerobj." + comm);
    return true;
             }
  catch(e){};
    }
    
if (typeof win.vieweremb != "undefined"){
  try{
    eval("win.vieweremb." + comm);
    return true;
             }
  catch(e){};
    }

return false;
}


// Set the pan,tilt,fov for QuickTime object
function setptf(){
if (!G.win || G.win.closed){return}
// if (window.opener && !window.opener.closed){}

var pan = document.getElementById("pan").value;
var tilt = document.getElementById("tilt").value;
var fov = document.getElementById("fov").value;
runprop(G.win.document,'SetPanAngle()',pan);
runprop(G.win.document,'SetTiltAngle()',tilt);
runprop(G.win.document,'SetFieldOfView()',fov);




}

// Reset pan,tilt,fov to their default values
function defview(){
if (!G.win || G.win.closed){return}
runprop(G.win.document,'ShowDefaultView()');

getptf();

}


// Print out pan,tilt,fov for a QuickTime object
function getptf(){
//if (window.opener && !window.opener.closed){}
if (!G.win || G.win.closed){return false}

if (!isVR()){return false};

var pan = getprop(G.win.document,'GetPanAngle()');
var tilt = getprop(G.win.document,'GetTiltAngle()');
var fov = getprop(G.win.document,'GetFieldOfView()');


// rect is a string of the form [x1,y1,x2,y2]. It is the rectangle of
// the display window in the browser.
var rect = getQTRectangle();
x1 = rect[0]; y1 = rect[1]; x2 = rect[2]; y2 = rect[3];


// Calculate the horizontal fov using the display window size and the
// vertical fov of the QTVR movie.
var displaywidth = x2 - x1,
    displayheight = y2 - y1,
    fovrad = fov * Math.PI/180; // convert from degrees to radians


var hfov = (180/Math.PI)*2*Math.atan(displaywidth*(Math.tan(fovrad/2))/displayheight);


var m = 1000;
pan = Math.round(pan*m)/m;
tilt = Math.round(tilt*m)/m;
fov = Math.round(fov*m)/m;
hfov = Math.round(hfov*m)/m;

document.getElementById("pan").value =   pan;
document.getElementById("tilt").value =  tilt;
document.getElementById("fov").value =   fov;
document.getElementById("hfov").value =   hfov;

miscstuff();


}

// List all properties for viewerobj and vieweremb
function allprops(){
var a="";
var b="";
var c;

if (G.win.document.getElementById("viewerobj")){
   a+="OBJECT Tag properties: <br>";
   pL = new Array();
   for (property in G.win.document.getElementById("viewerobj")){
     pL[pL.length] = String(property)};

   for (i=0;i<pL.length;i++){

try{
   eval("c = G.win.document.getElementById(\"viewerobj\")." + pL[i] +"()");
}
catch(e){eval("c = G.win.document.getElementById(\"viewerobj\")." + pL[i])};

a+=pL[i] + ", ";
       }

}


if (G.win.document.getElementById("vieweremb")){
 b+="<br><br><br>EMBED Tag properties: <br>";

   pL1 = new Array();
   for (property in G.win.document.getElementById("vieweremb")){
     pL1[pL1.length] = String(property)};

   for (i=0;i<pL1.length;i++){
try{
   eval("c = G.win.document.getElementById(\"vieweremb\")." + pL1[i]+"()");
}
catch(e){eval("c = G.win.document.getElementById(\"vieweremb\")." + pL1[i])};

b+=pL1[i]+", ";
       }
}

qqq = window.open();

qqq.document.open();
qqq.document.write(a+b);
qqq.document.close();

}


// Put HTML code into the G.win window
function makeqtvrpage(width,height,src,controller,cache,
    scale,bgcolor,kioskmode){
var a = unescape(src);
a = a.substring(a.indexOf(":")+1,a.length);
if (a.substring(0,1)=="/"){a = a.substring(1,a.length)};
if (a.substring(0,1)=="/"){a = a.substring(1,a.length)};
if (a.substring(0,1)=="/"){a = a.substring(1,a.length)};
if (a.substring(0,1)=="/"){a = a.substring(1,a.length)};


// Note: We have to add '\n' to various places, or else IE gets confused
var yy = "<html>\n<head>\n"+
"<meta http-equiv=\"Content-Type\" content=\"text/html; charset=us-ascii\">\n"+
"<title>" + a + "</title>\n\n"+

// Open the page to full size
"<script type=\"text/javascript\">\n" +
"<!--\n"+
"window.moveTo(0,0);\n" +
"window.resizeTo(screen.availWidth,screen.availHeight);\n " +
"window.focus();\n" +
"//-->\n" +
"</script>\n\n" +

"<style type=\"text/css\" media=\"screen\">\n"+
"<!--\n"+
"html { width: 100%; height: 100% }\n" +
"body {background-color: #e7e7ff; margin: 0px; padding: 0px; width: 100%; height: 100%; overflow: hidden }\n" +

// We try to make pano appear in the center (vertically and horizontally)
// by using a table.
"#qt { width: 100%; height: 100%; "+
      "margin: 0px; padding: 0px; border: 0px; border-spacing: 0px;" +
      " }\n" +
"#qt td {width: 100%; height: 100%; "+
      "margin: 0px; padding: 0px; border: 0px;" +
      "text-align: center; vertical-align: middle; }\n" +
"-->\n" +
"</style>\n\n" +
"</head>\n" +
"<body>\n" +

// We have to specify cellspacing here because IE does not seem to respond
// to the CSS 'border-spacing: 0px'
"<table id=\"qt\" border=\"0\" cellspacing=\"0\"><tr><td>\n\n";

var xx = "<object classid=\"clsid:02BF25D5-8C17-4B23-BC80-D3488ABDDC6B\" " +
  "width=\"" + width + "\" height=\"" + height + 
  "\" id=\"viewerobj\" " + // "\" name=\"viewerobj\" " +
  "codebase=\"http://www.apple.com/qtactivex/qtplugin.cab\">" +
  "<param name=\"src\" value=\""+src+"\">\n" +
  "<param name =\"controller\" value=\"" + controller + "\">\n" +
  "<param name =\"cache\" value=\"" + cache +"\">\n" +
  "<param name =\"scale\" value=\"" + scale + "\">\n" +
  "<param name =\"bgcolor\" value=\"" + bgcolor + "\">\n" +
  "<param name =\"kioskmode\" value=\"" + kioskmode + "\">\n" +
  "<param name=\"enablejavascript\" value=\"true\">\n" +

  "<embed src=\"" + src + 
  "\" id=\"vieweremb\" " + // "\" name=\"vieweremb\" " +
  "type=\"video/quicktime\" scale=\"" + scale + "\" " +
  "pluginspage=\"http://www.apple.com/quicktime/download/\" " +
  "width=\"" + width + "\" height=\"" + height + "\" " +
  "bgcolor=\"" + bgcolor + "\" controller=\"" + controller + "\" " +
  "enablejavascript=\"true\">\n"+
  "</embed></object>\n\n";

var zz = "</td></tr></table>\n"+
"</body>\n" +
"</html>";

G.win.document.open();
G.win.document.write(yy+xx+zz);
G.win.document.close();
}

// -->
